(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65316,       2087]*)
(*NotebookOutlinePosition[     71673,       2250]*)
(*  CellTagsIndexPosition[     70481,       2219]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Kapitel 1"]], "Subtitle"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Beschreibung von Diffusion"]], "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox[". Beschreibung von normaler Diffusion"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox[". Vorgehensweise"]
}], "Subsection"],

Cell[TextData[StyleBox[
"Historisch gibt es verschiedene Arten, Diffusion zu beschreiben. Im \
folgenden sollen nur einige davon vorgestellt werden, damit eine n\
\[ADoubleDot]here Auswahl getroffen werden kann, bevor die anomale Diffusion \
beschrieben wird."]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Ficksche Diffusion"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Die Fickschen Gesetze"
}], "Subsubsection"],

Cell["Zus\[ADoubleDot]tzlich zur Kontinuit\[ADoubleDot]tsgleichung", "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] + \[PartialD]\_x j[x, t] = 0\)], 
  "NumberedEquation",
  CellTags->"Kontinuit\[ADoubleDot]tsgleichung"],

Cell[TextData[{
  "mit der Dichte ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho][x, t]\)]],
  " und der Stromdichte ",
  Cell[BoxData[
      \(TraditionalForm\`j[x, t]\)]],
  " in den Koordinaten ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " ben\[ODoubleDot]tigt man eine sogenannte konstitutive oder wesentliche \
Gleichung, die einen weiteren Zusammenhang zwischen Stromdichte und Dichte \
herstellt."
}], "Text"],

Cell[TextData[{
  "Nach Fick ergibt das erste Ficksche Gesetz (vgl. ",
  ButtonBox["[Metz1996]",
    ButtonData:>{"Literatur.nb", "[Metz1996]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (6.2), S. 74) folgende Beziehung:"
}], "Text"],

Cell[BoxData[
    \(j[x, t] = \(-\[Lambda]\) \(\[PartialD]\_x \[Rho][x, t]\ .\)\)], 
  "NumberedEquation",
  CellTags->"1.Ficksches Gesetz"],

Cell[TextData[{
  "Der im ersten Fickschen Gesetz (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "1.Ficksches Gesetz"],
  ") enthaltene Diffusionskoeffizient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " ist eine Materialgr\[ODoubleDot]\[SZ]e, die sich mit den Abmessungen des \
Versuchsaufbaus r\[ADoubleDot]umlich und mit chemischen \
Ver\[ADoubleDot]nderungen desselben sogar auch zeitlich ver\[ADoubleDot]ndern \
kann. Diese Effekte sollen nicht den Schwerpunkt dieser Arbeit darstellen, \
wodurch im folgenden der Diffusionsparameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " fast \[UDoubleDot]berall eine echte Materialkonstante in Ort und Zeit \
ist."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "Durch Einsetzen des ersten Fickschen Gesetzes (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "1.Ficksches Gesetz"],
  ") in die Kontinuit\[ADoubleDot]tsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Kontinuit\[ADoubleDot]tsgleichung"],
  ") folgt das zweite Ficksche Gesetz, das bereits als Diffusionsgleichung \
gilt, hier noch um eine beliebige Steuergr\[ODoubleDot]\[SZ]e ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t]\)]],
  " erg\[ADoubleDot]nzt:"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] - 
        \[Lambda] \[PartialD]\_\(x\ x\)\[Rho][x, t] = \(s[x, t]\ .\)\)], 
  "NumberedEquation",
  CellTags->"2.Ficksches Gesetz"],

Cell[TextData[{
  "Wenn \[ADoubleDot]u\[SZ]ere Einfl\[UDoubleDot]sse fehlen (Steuergr\
\[ODoubleDot]\[SZ]e  ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t] \[Congruent] 0\)]],
  "), so besitzt auch die Kontinuit\[ADoubleDot]tsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Kontinuit\[ADoubleDot]tsgleichung"],
  ") weder Quellen noch Senken, so da\[SZ] das Raumintegral \[UDoubleDot]ber \
die Dichte ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho][x, t]\)]],
  " eine zeitliche Erhaltungsgr\[ODoubleDot]\[SZ]e darstellt. \
\[CapitalUDoubleDot]blicherweise wird aus diesem Grund die Dichte in der \
Theorie normiert. Die Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") taucht auch im Zusammenhang mit der Fourierschen Theorie der W\
\[ADoubleDot]rmeleitung auf, wobei dann die Dichte ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " durch die Temperatur ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " ersetzt wird."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Propagator der Fickschen Diffusion"
}], "Subsubsection"],

Cell[TextData[{
  "Der Propagator der Fickschen Diffusionsgleichung (Berechnung siehe Kapitel \
3 dieser Arbeit) ergibt aus dem Anfangswertproblem einer Diracschen \
Delta-Funktion (",
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]2, S. 624-627):"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x, t] = 
      \(\((Exp[\(-\(x\^2\/\(4\ \[Lambda]\ t\)\)\)]
              \/\@\(4  \[Pi]\ \[Lambda]\ t\))\)\ .\)\)], "NumberedEquation",
  CellTags->"Fickscher Diffusionspropagator"],

Cell[TextData[{
  "Die Fourier-Faltung der tats\[ADoubleDot]chlichen Anfangsverteilung mit \
dem Propagator ergibt die allgemeine L\[ODoubleDot]sung der homogenen \
Teilgleichung von Gleichung ",
  "(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ")",
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Normalverteilung und Einstein-Relation"
}], "Subsubsection"],

Cell[TextData[{
  "Der Propagator der Fickschen Diffusionsgleichung ist eine Gau\[SZ]sche \
Glockenkurve, die auch in der statistischen Theorie eine besondere Bedeutung \
besitzt (",
  ButtonBox["[Acz1961]",
    ButtonData:>{"Literatur.nb", "[Acz1961]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.3.5., S. 94-97). Sie ist 1809 allgemein von Gau\[SZ] mit der \
sogenannten Varianz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  ", der mittleren Summe der Streuquadrate, angegeben worden und hei\[SZ]t \
dann ",
  StyleBox["Normalverteilung",
    FontSlant->"Italic"],
  " (",
  ButtonBox["[BrS1987]",
    ButtonData:>{"Literatur.nb", "[BrS1987]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 5.1.2.2.2, S. 664):"
}], "Text"],

Cell[BoxData[
    \(f[x] = 
      \(\((Exp[\(-\(\((x - \[Mu])\)\^2\/\(2  \[Sigma]\^2\)\)\)]
              \/\@\(2  \[Pi]\ \[Sigma]\^2\))\)\ .\)\)], "NumberedEquation",
  CellTags->"Normalverteilung"],

Cell[TextData[{
  "Aus den Gleichungen",
  " (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fickscher Diffusionspropagator"],
  ") und (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Normalverteilung"],
  ") ergibt sich durch Koeffizientenvergleich sofort die Varianz",
  " des Fickschen Diffusionspropagators, n\[ADoubleDot]mlich ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = 2  \[Lambda]\ t\)]],
  ", was als Einstein-Relation bezeichnet wird."
}], "Text"],

Cell["\<\
Allgemein wird die Varianz aus den ersten drei Momenten einer Verteilung \
berechnet (siehe Anhang A dieser Arbeit).\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Normale Diffusion nach Cattaneo"
}], "Subsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Im Jahre 1948 ver\[ODoubleDot]ffentlichte C. Cattaneo in Rom eine Schrift \
",
  ButtonBox["[Cat1948]",
    ButtonData:>{"Literatur.nb", "[Cat1948]"},
    ButtonStyle->"Hyperlink"],
  ", in der eine molekularkinetisch begr\[UDoubleDot]ndete \
Diffusionsgleichung vorgestellt wird, die folgenderma\[SZ]en lautet (",
  ButtonBox["[Cat1948]",
    ButtonData:>{"Literatur.nb", "[Cat1948]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (22), S. 94):"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] + 
        \[Tau]\ \[PartialD]\_\(t\ t\)\[Rho][x, t] - 
        \[Lambda] \[PartialD]\_\(x\ x\)\[Rho][x, t] = \(s[x, t]\ .\)\)], 
  "NumberedEquation",
  CellTags->"Cattaneo-Gleichung"],

Cell[TextData[{
  "Hier taucht noch eine spezifische Zeit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " auf, die die Endlichkeit der charakteristischen Geschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " bei der Diffusion ber\[UDoubleDot]cksichtigt. Dieser Zusammenhang wird \
bei Cattaneo angedeutet (",
  ButtonBox["[Cat1948]",
    ButtonData:>{"Literatur.nb", "[Cat1948]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (23), S. 94) und bei T. F. Nonnenmacher (",
  ButtonBox["[Non1980]",
    ButtonData:>{"Literatur.nb", "[Non1980]"},
    ButtonStyle->"Hyperlink"],
  ", Text nach Formel (4), S. 363) explizit wiederholt:"
}], "Text"],

Cell[BoxData[
    \(\[Lambda] = v\^2\ \(\[Tau]\ .\)\)], "NumberedEquation",
  CellTags->"Diffusionskonstante"],

Cell[TextData[{
  "Ein Zusammenhang zur Boltzmannschen Sto\[SZ]dynamik wird in diesen \
Arbeiten hergestellt, wobei ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " proportional zur endlichen Zeit zwischen zwei St\[ODoubleDot]\[SZ]en \
ist."
}], "Text"],

Cell[TextData[{
  "Wird ein Grenz\[UDoubleDot]bergang ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] \[Rule] 0\)]],
  " so gebildet, da\[SZ] der Diffusionskoeffizient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " dabei konstant bleibt, so wird die charakteristische Geschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " unendlich gro\[SZ], und die Ficksche Diffusionsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") ist zur\[UDoubleDot]ckgewonnen."
}], "Text"],

Cell[TextData[{
  "Die Gleichung von Cattaneo ist vom hyperbolischen Typ und recht schwierig \
zu l\[ODoubleDot]sen. Nicht einmal die vollst\[ADoubleDot]ndigen Momente der \
Propagatoren sind in der Literatur (",
  ButtonBox["[dJag1980]",
    ButtonData:>{"Literatur.nb", "[dJag1980]"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["[CM1997]",
    ButtonData:>{"Literatur.nb", "[CM1997]"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["[MN1998]",
    ButtonData:>{"Literatur.nb", "[MN1998]"},
    ButtonStyle->"Hyperlink"],
  ") zu finden. Die Varianz des statischen (mit Anfangsgeschwindigkeit Null) \
L\[ODoubleDot]sungspropagators wird hier ohne Herleitung mit"
}], "Text"],

Cell[BoxData[
    \(\[Sigma]\^2 = 
      2  \[Lambda]\ \((t - \[Tau])\) + 
        2  \[Lambda]\ \[Tau]\ Exp[\(-t\)/\[Tau]]\)], "NumberedEquation",
  CellTags->"Varianz der Cattaneo-Gleichung"],

Cell[TextData[{
  "angegeben (Berechnungsverfahren: siehe Kapitel 2). Dies bedeutet nach dem \
Varianztheorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  "), da\[SZ] die L\[ODoubleDot]sung des statischen Cattaneo-Propagators als \
Fourier-Faltung zweier Funktionen gegeben ist. Die Varianz beginnt f\
\[UDoubleDot]r kleine Zeiten mit der Varianz (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Wellen-Varianz"],
  ") einer Wellengleichung, die im Rahmen dieser Arbeit als Wellenvarianz \
bezeichnet wird: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = \(\[Lambda]\/\[Tau]\) t\^2\)]],
  ", und geht f\[UDoubleDot]r gro\[SZ]e Zeiten ",
  Cell[BoxData[
      \(TraditionalForm\`t >> \[Tau]\)]],
  " in eine zeitverschobene Ficksche Diffusionsvarianz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = 2  \[Lambda]\ t\)]],
  " \[UDoubleDot]ber."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "Ein Vergleich der als Wellenvarianz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = \(\[Lambda]\/\[Tau]\) t\^2\)]],
  " beginnenden Cattaneo-Varianz (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianz der Cattaneo-Gleichung"],
  ") mit der \[UDoubleDot]blichen Wellenvarianz (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Wellen-Varianz"],
  ") liefert eine Deutung der charakteristischen Geschwindigkeit des \
Diffusionsparameters (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") als Wellenausbreitungsgeschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Die Cattaneo-Gleichung unterscheidet sich in mathematischer Hinsicht nicht \
von der sogenannten Telegraphengleichung (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]204, Gln. (8) und (9), S. 480), die in der Elektrodynamik zur \
Beschreibung einer ged\[ADoubleDot]mpften elektromagnetischen Welle \
hergeleitet werden kann. Die Ph\[ADoubleDot]nomene ",
  StyleBox["ged\[ADoubleDot]mpfte Welle",
    FontSlant->"Italic"],
  " und ",
  StyleBox["Diffusion ",
    FontSlant->"Italic"],
  "sind aber m\[ODoubleDot]glicherweise doch nicht dasselbe. Aus diesem \
Grunde kann auch noch nach weiteren Modellen zur Diffusion gesucht werden."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Normale Diffusion nach dem Diffusionsprinzip"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Verbale Formulierung des Diffusionsprinzips"
}], "Subsubsection"],

Cell[TextData[{
  "Analog zum Huyghensschen Prinzip der Wellenausbreitung (",
  ButtonBox["[BeS1945]",
    ButtonData:>{"Literatur.nb", "[BeS1945]"},
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["I",
    FontWeight->"Bold"],
  ", \[Section]76, S. 362-369) aus dem Jahre 1678 l\[ADoubleDot]\[SZ]t sich \
auch ein Diffusionsprinzip beschreiben, das wie folgt lauten \
k\[ODoubleDot]nnte:"
}], "Text"],

Cell["\<\
Jeder Punkt einer Materieverteilung ist Ausgangspunkt einer neuen elementaren \
Materieumverteilung. Die elementare Materieumverteilung erfolgt so, da\[SZ] \
der zur Verf\[UDoubleDot]gung stehende Raum ausgenutzt wird. Die \
\[CapitalUDoubleDot]berlagerung aller neuen elementaren Materieumverteilungen \
ergibt die neue Materieverteilung.\
\>", "Text",
  TextAlignment->Left,
  FontSlant->"Italic"],

Cell["\<\
Der wesentliche Unterschied zum Prinzip der Wellenausbreitung besteht darin, \
da\[SZ] keine Einh\[UDoubleDot]llende der neuen Elementarprozesse vorkommt.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Superponierbarkeit"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Beim Diffusionsprinzip und beim Huyghensschen Prinzip der \
Wellenausbreitung ist gleich, da\[SZ] die Separation der Dynamik in \
elementare Einzelprozesse m\[ODoubleDot]glich ist, die ihrerseits sehr \
einfach sind. Die globale Diffusion wird demnach durch eine lokale Konflusion \
(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") (lat. confluere: zusammenflie\[SZ]en) beschrieben."
}], "Text"],

Cell[TextData[{
  "Zur mathematischen Beschreibung superponierbarer \
(\[UDoubleDot]berlagerungsf\[ADoubleDot]higer) Ph\[ADoubleDot]nomene dienen \
lineare Gleichungen (",
  ButtonBox["[St\[ODoubleDot]1998]",
    ButtonData:>{"Literatur.nb", "[Stoe1998]"},
    ButtonStyle->"Hyperlink"],
  ", 7.1.1.7, S. 201). Die Superponierbarkeit diffusiver Prozesse wird im \
folgenden als gegeben angesetzt, weshalb auch nur noch lineare Gleichungen \
diskutiert werden. Auch die Gleichungen (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") und (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") sind linear und lassen deshalb die zus\[ADoubleDot]tzliche Ber\
\[UDoubleDot]cksichtigung von Steuergr\[ODoubleDot]\[SZ]en zu. In der \
Literatur tauchen auch nichtlineare Diffusionsgleichungen (z. B. ",
  ButtonBox["[HD1998]",
    ButtonData:>{"Literatur.nb", "[HD1998]"},
    ButtonStyle->"Hyperlink"],
  ") auf, die im Rahmen dieser Arbeit nicht weiterverfolgt werden."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Differenzengleichung"
}], "Subsubsection"],

Cell[TextData[{
  "Das angegebene Diffusionsprinzip l\[ADoubleDot]\[SZ]t sich am einfachsten \
als lineare Differenzengleichung in einer einzigen Raumdimension modellieren, \
die auf radialsymmetrische Fragestellungen verallgemeinert werden kann. Mit \
der Dichteverteilung ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho][x, t]\)]],
  " ergibt dieser Ansatz mit einer zum Erhalt der physikalischen Einheiten \
eingef\[UDoubleDot]hrten charakteristischen Geschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " und der Zeitdifferenz ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t\)]],
  " folgende Gleichung f\[UDoubleDot]r einen elementaren Proze\[SZ]:"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x - v\ \[CapitalDelta]t, t - \[CapitalDelta]t]\/2 + 
        \[Rho][x + v\ \[CapitalDelta]t, t - \[CapitalDelta]t]\/2 = 
      \(\[Rho][x, t]\ .\)\)], "NumberedEquation",
  CellTags->"Differenzengleichung"],

Cell[TextData[{
  "Bei der Diffusion erfolgt die Bewegung eines Einzelteilchens fast immer im \
Zick-Zack-Kurs, so da\[SZ] die maximale Geschwindigkeit der Diffusion im \
Rahmen dieses Modells durch die globale Schallgeschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " (Wellenausbreitungsgeschwindigkeit) des Systems gegeben ist: Beide \
Effekte (Diffusion und Welle) sind als durch Einzelst\[ODoubleDot]\[SZ]e \
bedingt verstehbar."
}], "Text"],

Cell[TextData[{
  "Will man den atomaren Charakter der Materie betonen, so mu\[SZ] ber\
\[UDoubleDot]cksichtigt werden, da\[SZ] zwischen zwei Einzelst\[ODoubleDot]\
\[SZ]en tats\[ADoubleDot]chlich endlich viel Zeit, n\[ADoubleDot]mlich  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t > 0\)]],
  ", vergeht. F\[UDoubleDot]r derartige Betrachtungen und auch \
f\[UDoubleDot]r Computer-Simulationen stellt die Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") einen m\[ODoubleDot]glichen Zugang zur Beschreibung von Diffusionsvorg\
\[ADoubleDot]ngen dar, der freilich verfeinert werden kann."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sung der Differenzengleichung"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Die angegebene Differenzengleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") besitzt eine im Sinne des Abtasttheorems aus der Nachrichtentechnik (",
  ButtonBox["[Mar1986]",
    ButtonData:>{"Literatur.nb", "[Mar1986]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. 6, S. 127-131) eindeutige L\[ODoubleDot]sung f\[UDoubleDot]r ein \
Anfangswertproblem, das mit einer normierten Gesamtverteilung bei ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " zur Zeit ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " beginnt:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[Rho][x, t]\), "=", 
      RowBox[{
        RowBox[{
        \(1\/\(2  v\ \[CapitalDelta]t\)\), \(1\/2\^\(t\/\[CapitalDelta]t\)\), 
          
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {\(t\/\[CapitalDelta]t\)},
                {\(\(x + v\ t\)\/\(2  v\ \[CapitalDelta]t\)\)}
                }], "\[NegativeThinSpace]", ")"}]}], "=", 
        \(\((\(1\/\(2  v\ \[CapitalDelta]t\)\) 
              \(1\/2\^\(t\/\[CapitalDelta]t\)\) 
              \(\((t\/\[CapitalDelta]t)\)!
                  \)\/\(\(\((\(x + v\ t\)\/\(2  v\ \[CapitalDelta]t\))\)!\) 
                  \(\((\(x - v\ t\)\/\(2  v\ \[CapitalDelta]t\))\)!\)\))\).
          \)}]}]], "NumberedEquation",
  CellTags->"Binomialverteilung"],

Cell[TextData[{
  "Die Verifikation der Binomialverteilung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") als L\[ODoubleDot]sung der Diffusionsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") ist durch elementare Rechnung m\[ODoubleDot]glich. Die \
Normierungskonstante wurde au\[SZ]erdem mit ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(2  v\ \[CapitalDelta]t\)\)]],
  " festgelegt."
}], "Text"],

Cell[TextData[{
  "Die Varianz der symmetrischen Binomialverteilung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") ist bekannt, wenn die Koeffizienten nicht gewichtet sind: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Sigma]\^2\), "[", 
            RowBox[{\(2\^\(\(-n\)\ \)\), 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"n"},
                    {\(k - n\/2\)}
                    }], "\[NegativeThinSpace]", ")"}]}], "]"}], " ", "=", 
          \(n\/4\)}], TraditionalForm]]],
  ". Die Verwendung der Substitution ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 2  v\ \[CapitalDelta]t\ k\)]],
  " bei der Varianzberechnung der normierten Binomialverteilung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") ergibt"
}], "Text"],

Cell[BoxData[
    \(\(\[Sigma]\^2 = 
      \(\(1\/\(2  v\ \[CapitalDelta]t\)\) \(\((2  v\ \[CapitalDelta]t)\)\^3\) 
          t\/\(4  \[CapitalDelta]t\) = 
        \(\[CapitalDelta]t\ v\^2\ t = 2  \[Lambda]\ t\)\)\ , \)\)], 
  "NumberedEquation",
  CellTags->"Varianz der Binomialverteilung"],

Cell[TextData[{
  "wobei die letztgenannte Identit\[ADoubleDot]t mit ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 2  \[Tau]\)]],
  " in der Beziehung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") folgt."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". \[CapitalUDoubleDot]bergang zu einer Differentialgleichung"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Wird die Differenzengleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") so interpretiert, da\[SZ] ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t\)]],
  " die Variable einer Taylor-Entwicklung sein soll (die \
L\[ODoubleDot]sungsfunktion sei also stetig und differenzierbar), so ergibt \
die Taylor-Entwickung dieser Differenzengleichung folgende \
Differentialgleichung mit Fehlerordnung ",
  Cell[BoxData[
      \(TraditionalForm\`O[\[CapitalDelta]t\^2]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] - 
        \[CapitalDelta]t\/2\ \[PartialD]\_\(t\ t\)\[Rho][x, t] - 
        \(\(v\^2\ \[CapitalDelta]t\)\/2\) \[PartialD]\_\(x\ x\)\[Rho][x, t] = 
      \(s[x, t]\ .\)\)], "NumberedEquation",
  CellTags->"modifizierte Cattaneo-Gleichung"],

Cell[TextData[{
  "Es handelt sich um eine elliptische Modifikation der Cattaneo-Gleichung (",
  
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  "), wobei das Aussehen des Diffusionskoeffizienten (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") mit ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 2  \[Tau]\)]],
  " best\[ADoubleDot]tigt wird. Auch die modifizierte Cattaneo-Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") l\[ADoubleDot]\[SZ]t sich nur schwer l\[ODoubleDot]sen. Hier bereitet \
bereits die Varianzberechnung des statischen L\[ODoubleDot]sungspropagators \
ernsthafte Schwierigkeiten."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Weiteres Vorgehen"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Grenz\[UDoubleDot]bergang zur Fickschen Diffusionsgleichung"
}], "Subsubsection"],

Cell[TextData[{
  "Der Grenz\[UDoubleDot]bergang ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] \[Rule] 0\)]],
  " bei Erhalt des Diffusionskoeffizienten ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " in Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") \[UDoubleDot]berf\[UDoubleDot]hrt die Cattaneo-Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") in die Ficksche Diffusionsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  "). Dasselbe Ergebnis erh\[ADoubleDot]lt man beim Grenz\[UDoubleDot]bergang \
",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t \[Rule] 0\)]],
  ", wenn die Ausbreitungsgeschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " in der modifizierten Cattaneo-Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") so nach Unendlich geht, da\[SZ] der Diffusionsparameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " gem\[ADoubleDot]\[SZ] Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") konstant bleibt."
}], "Text"],

Cell[TextData[{
  "Aus der L\[ODoubleDot]sung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") wird durch diesen Grenz\[UDoubleDot]bergang der Propagator (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fickscher Diffusionspropagator"],
  ") der Fickschen Diffusion:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(P[x, t]\), "=", 
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(t\/\[CapitalDelta]t\)},
                  {\(\(x + v\ t\)\/\(2\ v\ \[CapitalDelta]t\)\)}
                  }], "\[NegativeThinSpace]", ")"}], 
            \(2\ v\ \[CapitalDelta]t\ 2\^\(t\/\[CapitalDelta]t\)\)], 
          "\[TildeTilde]", 
          \(Exp[\(-\(x\^2\/\(2\ v\^2\ \[CapitalDelta]t\ t\)\)\)]\/\(2\ v\ 
                \[CapitalDelta]t \@\( \[Pi]\/2\ t\/\[CapitalDelta]t\)\)\)}], 
        "=", \(\((
            Exp[\(-\(x\^2\/\(4  \[Lambda]\ t\)\)\)]
                \/\@\(4\ \[Pi]\ \[Lambda]\ t\))\)\ .\)}]}]], 
  "NumberedEquation",
  CellTags->"Binomialer Grenz\[UDoubleDot]bergang"],

Cell[TextData[{
  "In diesem Zusammenhang dankt der Verfasser Herrn Professor Dr. P. Chvosta \
(Prag) f\[UDoubleDot]r eine ausf\[UDoubleDot]hrliche Diskussion \
\[UDoubleDot]ber den simultanen Grenz\[UDoubleDot]bergang (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialer Grenz\[UDoubleDot]bergang"],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Hypothese zur Varianz"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Die Varianz (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianz der Binomialverteilung"],
  ") der Binomialverteilung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") ist gleich der Varianz des Fickschen Diffusionspropagators (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fickscher Diffusionspropagator"],
  "), n\[ADoubleDot]mlich ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sigma]\^2 = \(\[CapitalDelta]t\ v\^2\ t = 2  \[Lambda]\ t\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Damit besitzt die normale Diffusion unabh\[ADoubleDot]ngig von der Frage \
nach der Endlichkeit oder Unendlichkeit der charakteristischen \
Wellenausbreitungsgeschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " eine einheitliche Varianz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  ", die proportional mit der Me\[SZ]zeit ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " w\[ADoubleDot]chst. In den Arbeiten A. Einsteins, der die Endlichkeit von \
Wellenausbreitungsgeschwindigkeiten f\[UDoubleDot]r wesentlich hielt, liegt \
also kein innerer Widerspruch, da die Einstein-Relation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianz der Binomialverteilung"],
  ") nicht nur f\[UDoubleDot]r den Fickschen Diffusionspropagator zutrifft, \
sondern auch f\[UDoubleDot]r die diskrete Binomialverteilung. Ein Propagator \
beginnt zur Zeit ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] 0\)]],
  " als Diracsche Delta-Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x]\)]],
  ", deren Varianz Null ist. Die Varianz macht keine Aussage \[UDoubleDot]ber \
die genaue Form einer Verteilungsfunktion."
}], "Text"],

Cell[TextData[{
  "Es liegt die Hypothese nahe, da\[SZ] die elliptische Modifikation der \
Cattaneo-Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") gegen\[UDoubleDot]ber der parabolischen Fickschen Diffusionsgleichung (",
  
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") oder der Differenzengleichung der Binomialverteilung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") keine grundlegend verschiedene Varianz besitzt. Nach der \
Einstein-Relation beschreiben alle drei Gleichungstypen die ",
  StyleBox["normale Diffusion",
    FontSlant->"Italic"],
  " im Rahmen eines entsprechenden Modells. Die hyperbolische \
Cattaneo-Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") besitzt asymptotisch f\[UDoubleDot]r gro\[SZ]e Zeiten ebenfalls die \
Varianz der normalen Diffusion."
}], "Text"],

Cell[TextData[{
  "Die Benennung von partiellen linearen Differentialgleichungen zweiter \
Ordnung nach Kegelschnitten h\[ADoubleDot]ngt mit der \
Charakteristiken-Methode (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]146, S. 282-286) zusammen, die im Rahmen dieser Arbeit keine \
Anwendung finden soll."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Klassifikation von Diffusion"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". ",
  "Vergleich von Me\[SZ]werten mit Theoriepropagatoren"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Problem"
}], "Subsubsection"],

Cell["\<\
Ein Theoriepropagator beginnt stets mit einer Diracschen Delta-Funktion als \
Anfangswertproblem. Dieses Anfangswertproblem ist allerdings bei keinem \
einzigen Experiment streng realisierbar.\
\>", "Text"],

Cell["\<\
Vielmehr ergibt sich die allgemeine L\[ODoubleDot]sung einer partiellen \
linearen Differentialgleichung (zumindest f\[UDoubleDot]r konstante \
Koeffizienten) als Fourier-Faltung des zeitabh\[ADoubleDot]ngigen Propagators \
mit der zeitunabh\[ADoubleDot]ngigen Anfangsverteilung.\
\>", "Text"],

Cell["\<\
Diese \[CapitalUDoubleDot]berlegungen stellen zun\[ADoubleDot]chst einmal die \
Klassifikation diffusiver Prozesse \[UDoubleDot]ber die Einstein-Relation in \
Frage, da nicht der Propagator selbst, sondern nur eine Fourier-Faltung mit \
diesem Propagator gemessen wird.\
\>", "Text"],

Cell["\<\
Ein direkter Vergleich zwischen Me\[SZ]werten und theoretisch berechneten \
Propagatoren ist deshalb nicht einfach.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Varianztheorem"
}], "Subsubsection"],

Cell[TextData[{
  "In diesem Zusammenhang ist das Varianztheorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") von besonderer Bedeutung (Beweis siehe Anhang A dieser Arbeit), das \
einen universellen Vergleich von Theoriepropagatoren linearer Gleichungen mit \
Me\[SZ]werten erm\[ODoubleDot]glicht. Es beschreibt die Varianz einer \
Fourier-Faltung als Summe der Varianzen der Faltungskomponenten:"
}], "Text"],

Cell[BoxData[
    \(\(\[Sigma]\^2\)[f[x]*g[x]] = 
      \(\(\[Sigma]\^2\)[
          \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[x - y] g[y] 
              \[DifferentialD]y] = 
        \(\[Sigma]\^2\)[f[x]] + \(\(\[Sigma]\^2\)[g[x]]\ .\)\)\)], 
  "NumberedEquation",
  CellFrame->True,
  CellTags->"Varianztheorem"],

Cell[TextData[{
  "Das \[UDoubleDot]ber eine lineare Gleichung beschriebene System wird durch \
eine Fourier-Faltung aus dem zeitabh\[ADoubleDot]ngigen Propagator ",
  Cell[BoxData[
      \(TraditionalForm\`p[x, t]\)]],
  " und der zeitunabh\[ADoubleDot]ngigen Anfangsverteilung ",
  Cell[BoxData[
      \(TraditionalForm\`f[x, t\_0]\)]],
  " beschrieben. Die Fourier-Faltung mit einer Diracschen Delta-Funktion \
(siehe Kapitel 2 dieser Arbeit) ergibt stets die andere gefaltete Funktion:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Delta][x - y] g[y] 
          \[DifferentialD]y = \(g[x]\ .\)\)], "NumberedEquation",
  CellTags->"Delta-Faltung"],

Cell[TextData[{
  "Mit den beiden Einsichten (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") und (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Faltung"],
  ") folgt bei einem entsprechenden Varianzabgleich von Me\[SZ]daten die \
Varianz des Propagators:"
}], "Text",
  PageBreakAbove->True],

Cell[BoxData[
    \(\(\[Sigma]\^2\)[f[x, t\_0]*p[x, t - t\_0]] - 
        \(\[Sigma]\^2\)[f[x, t\_0]*\[Delta][x]] = 
      \(\(\[Sigma]\^2\)[p[x, t - t\_0]]\ .\)\)], "NumberedEquation",
  CellTags->"Varianzabgleich"],

Cell["\<\
Der Vergleich von Theorie und Messung ist also \[UDoubleDot]ber die Varianz \
recht einfach.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Bedeutung des Varianztheorems"
}], "Subsubsection"],

Cell["\<\
Die Varianz von Me\[SZ]werten l\[ADoubleDot]\[SZ]t sich immer errechnen. Die \
Varianz einer Theoriefunktion ist dann errechenbar, wenn die Funktionswerte \
des Raumintervalls ab einer klar definierbaren Stelle au\[SZ]erhalb des Me\
\[SZ]bereichs auf Null gesetzt werden k\[ODoubleDot]nnen.\
\>", "Text"],

Cell["\<\
Eine Theoriefunktion beschreibt Me\[SZ]werte besonders dann recht gut, wenn \
au\[SZ]erhalb des Me\[SZ]fensters der numerische Wert der Theoriefunktion \
praktisch Null ist. Die Momentenintegrale und auch die Varianz \
k\[ODoubleDot]nnen dann meist noch problemlos mit unendlichen Integralgrenzen \
errechnet werden.\
\>", "Text"],

Cell[TextData[{
  "Das Varianztheorem ",
  "(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") ist ein universeller Zugang, um die Dynamik komplexer (komplizierter) \
linearer Systeme mit entsprechenden Me\[SZ]werten vergleichen zu k\
\[ODoubleDot]nnen. Besonders die Falsifikation einer Theorie ist \
\[UDoubleDot]ber den Varianzabgleich (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianzabgleich"],
  ") m\[ODoubleDot]glich."
}], "Text"],

Cell["\<\
Auf diese Weise k\[ODoubleDot]nnen viele verschiedene Theorien schnell und \
sicher mit realen Me\[SZ]werten verglichen werden.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Klassifikation von Transportprozessen \[UDoubleDot]ber die Varianz"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Best\[ADoubleDot]tigung der Einstein-Relation"
}], "Subsubsection"],

Cell[TextData[{
  "Im Falle der normalen Diffusion f\[UDoubleDot]hrt der Varianzabgleich (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianzabgleich"],
  ") auf eine Best\[ADoubleDot]tigung der Einstein-Relation auch f\
\[UDoubleDot]r Messungen, die nicht mit der Varianz Null beginnen. Die Frage \
nach der Endlichkeit der charakteristischen Geschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " mu\[SZ] hierbei nicht ausdiskutiert werden!"
}], "Text"],

Cell[TextData[{
  "F\[UDoubleDot]r diese Arbeit gen\[UDoubleDot]gt es also, die Varianten zur \
Fickschen Diffusionsgleichung ",
  "(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") so zu modellieren, da\[SZ] sie zum einen m\[ODoubleDot]glichst einfach \
gel\[ODoubleDot]st werden k\[ODoubleDot]nnen und zum anderen einer \
erweiterten Einstein-Relation gen\[UDoubleDot]gen, die auch ",
  StyleBox["anomale Diffusion",
    FontSlant->"Italic"],
  " beschreibt."
}], "Text"],

Cell[TextData[{
  "Diese Varianten sind vor allem in Form von ",
  StyleBox["fraktionalen Differentialgleichungen",
    FontSlant->"Italic"],
  " gegeben. Ihre L\[ODoubleDot]sungspropagatoren sind oft nur ",
  StyleBox["Foxsche H-Funktionen",
    FontSlant->"Italic"],
  " (siehe Kapitel 2 dieser Arbeit), die analytisch und numerisch recht \
angenehm sind."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Varianz des statischen Wellenpropagators"
}], "Subsubsection",
  PageBreakAbove->True],

Cell["Die Wellengleichung", "Text"],

Cell[BoxData[
    \(\[PartialD]\_\(t\ t\)\[Rho][x, t] - 
        \(v\^2\) \[PartialD]\_\(x\ x\)\[Rho][x, t] = 0\)], "NumberedEquation",\

  CellTags->"Wellen-Gleichung"],

Cell["\<\
besitzt ebenfalls eine zeitabh\[ADoubleDot]ngige Varianz des statischen \
Propagators:\
\>", "Text"],

Cell[BoxData[
    \(\[Rho][x, t] = 
      \(\((\(\[Delta][x - v\ t] + \[Delta][x + v\ t]\)\/2)\)\ .\)\)], 
  "NumberedEquation",
  CellTags->"Wellen-L\[ODoubleDot]sung"],

Cell["\<\
Das gemittelte Streuquadrat nimmt anschaulich mit dem Quadrat der Zeit zu:\
\>", "Text"],

Cell[BoxData[
    \(\[Sigma]\^2 = \(v\^2\) \(t\^2\ .\)\)], "NumberedEquation",
  CellTags->"Wellen-Varianz"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Klassifikationsschema diffusiver Prozesse"
}], "Subsubsection"],

Cell[TextData[{
  "Normale Diffusion zeichnet sich \[LongDash] unabh\[ADoubleDot]ngig von der \
Gestalt der Anfangsbedingungen und von der Existenz einer maximalen \
Ausbreitungsgeschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " \[LongDash] durch eine Proportionalit\[ADoubleDot]t der statischen \
Propagatorvarianz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " zur Me\[SZ]zeit ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " aus (Einstein-Relation)."
}], "Text"],

Cell[TextData[{
  "Ein allgemein diffusiver Proze\[SZ] zeichnet sich durch eine streng \
monoton wachsende Varianz des statischen Propagators aus, wobei das Wachstum \
durch ein Potenzgesetz in der Zeit beschrieben wird (",
  ButtonBox["[WGMN1997]",
    ButtonData:>{"Literatur.nb", "[WGMN1997]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt ",
  StyleBox["V",
    FontWeight->"Bold"],
  ", S. 103-104; ",
  ButtonBox["[ZSKN1999]",
    ButtonData:>{"Literatur.nb", "[ZSKN1999]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt ",
  StyleBox["I",
    FontWeight->"Bold"],
  ", S. 1292):"
}], "Text"],

Cell[BoxData[
    \(\(\(\[Sigma]\^2\)~\(t\^\(\ \[Alpha]\)\)\ .\)\)], "NumberedEquation",
  CellTags->"Diffusionsvarianz"],

Cell[TextData[{
  "Die Potenz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " der Diffusionsvarianz (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionsvarianz"],
  ") erm\[ODoubleDot]glicht folgende Klassifikation, die fortan gelte:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Alpha] < 1\)]],
  ":\tanomal langsame Diffusion (Subdiffusion),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1\)]],
  ":\t\tnormale Diffusion (Einstein-Relation),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Alpha] < 2\)]],
  ":\tanomal schnelle Diffusion (Superdiffusion),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 2\)]],
  ":\t\tballistischer Transport (Wellenausbreitung),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 2\)]],
  ":\t\tturbulenter Transport."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "Zur Ermittlung der Potenz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " wird der Varianzabgleich doppelt logarithmisch als Gerade aufgetragen, \
also ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalDelta]\[Sigma]\^2 = 
        \(\[Sigma]\^2\)[t] - \(\[Sigma]\^2\)[t\_0]\)]],
  " \[UDoubleDot]ber ",
  Cell[BoxData[
      \(TraditionalForm\`t - t\_0\)]],
  ". Derartige doppelt logarithmische Schaubilder sind vor allem dann Ursache \
f\[UDoubleDot]r Trugschl\[UDoubleDot]sse, wenn der Varianzabgleich (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianzabgleich"],
  ") fehlt. Die Steigung ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " der sich ergebenden Gerade entspricht bei unverzerrter Darstellung der \
Potenz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " von ",
  Cell[BoxData[
      \(TraditionalForm\`t\^\(\ \[Alpha]\)\)]],
  "."
}], "Text"],

Cell["\<\
Alle Prozesse, deren Propagatorvarianzen nicht mit einem zeitlichen \
Potenzgesetz bescheibbar sind oder nicht einmal streng monoton wachsen, sind \
nicht als diffusive Prozesse zu betrachten. Dazu geh\[ODoubleDot]rt etwa die \
Autoverteilung in Ulm oder die Verteilung von Ameisen in und um einen \
Ameisenhaufen herum.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Weitere Aspekte der Diffusionsbeschreibung"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Umgang mit Drift in der Dynamik"
}], "Subsubsection"],

Cell[TextData[{
  "Es ist umstritten, ob bei der Beschreibung von Diffusion auch eine \
zeitliche Ver\[ADoubleDot]nderung des Erwartungswertes der \
Verteilungsfunktion zul\[ADoubleDot]ssig ist. Sicher ist, da\[SZ] derartige \
\[CapitalUDoubleDot]berlegungen zum einen an der Varianz nichts ver\
\[ADoubleDot]ndern und zum anderen eine radialsymmetrische Verallgemeinerung \
von einer Raumdimension auf mehrere Raumdimensionen verhindern, da diese \
Verallgemeinerung bei Anwesenheit von Drift zu Quellen oder Senken des \
transportierten Materials f\[UDoubleDot]hrt und somit der \
urspr\[UDoubleDot]nglich angesetzten Kontinuit\[ADoubleDot]tsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Kontinuit\[ADoubleDot]tsgleichung"],
  ") widerspricht."
}], "Text"],

Cell[TextData[{
  "Die Diskussion von Drifttermen, wie sie besonders im Rahmen der \
Fokker-Planck-Gleichungen beliebt ist (",
  ButtonBox["[Ris1984]",
    ButtonData:>{"Literatur.nb", "[Ris1984]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 1.2.1, S. 4-5; ",
  ButtonBox["[vKam1984]",
    ButtonData:>{"Literatur.nb", "[vKam1984]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. X.3, S. 291-293), ist daher nicht der Schwerpunkt der hier \
vorgelegten Arbeit."
}], "Text"],

Cell[TextData[{
  "Vielmehr wird im Rahmen dieser Arbeit der ",
  StyleBox["Schwerpunktsatz",
    FontSlant->"Italic"],
  " als gegeben angesetzt und ist auch f\[UDoubleDot]r das Experiment \
anzustreben. Drift kann mit Sicherheit die Form einer Verteilungsfunktion \
zeitlich ver\[ADoubleDot]ndern, w\[ADoubleDot]hrend die Varianz davon unabh\
\[ADoubleDot]ngig sein sollte."
}], "Text"],

Cell["\<\
Um also zwei verschiedene Theorien mit jeweils identischem Varianzverhalten \
anhand von Me\[SZ]werten vergleichen zu k\[ODoubleDot]nnen, ist das Fehlen \
einer Drift (zeitliche Ver\[ADoubleDot]nderung des Erwartungswerts) beim \
Versuchsaufbau anhand der Me\[SZ]werte nachzuweisen, bevor eine der beiden \
Theorien bevorzugt werden kann.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Verallgemeinerung auf mehrere Raumdimensionen"
}], "Subsubsection"],

Cell[TextData[{
  "Anschaulich kann nach Rayleigh (",
  ButtonBox["[Fel1971]",
    ButtonData:>{"Literatur.nb", "[Fel1971]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt I.10(e), S. 32-33) eine isotrope \
(richtungsunabh\[ADoubleDot]ngige) Dynamik auf eine einzige Raumdimension \
abgebildet werden."
}], "Text"],

Cell[TextData[{
  "Das \[ADoubleDot]lteste Beispiel f\[UDoubleDot]r eine derartige \
Beschreibung stammt von L. Euler bei der Diskussion der dreidimensionalen \
Wellengleichung im Vergleich mit der eindimensionalen (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", Gln.(26)-(30), S. 421 und S. 465)."
}], "Text",
  PageBreakAbove->True],

Cell[TextData[{
  "Der zugeh\[ODoubleDot]rige Laplace-Operator verwandelt sich in diesem Fall \
gem\[ADoubleDot]\[SZ] der Transformation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi][r, t] = P[r, \ t]\/f[r]\)]],
  ", wobei ",
  Cell[BoxData[
      \(TraditionalForm\`f[r]\)]],
  " das entsprechende Abstandsgesetz angibt, im Falle der Kugelwelle also ",
  Cell[BoxData[
      \(TraditionalForm\`f[r] = \@\(4  \[Pi]\ r\^2\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\^2 P[r, t]\/\[PartialD]r\^2 \[LeftRightArrow] 
      \(\((\(1\/f[r]\) 
            \[PartialD]\^2\((f[r]\ \[Phi][r, t])\)\/\[PartialD]r\^2)\)\ .
        \)\)], "NumberedEquation",
  CellTags->"Eulerscher Trick"],

Cell["\<\
Auf diese Weise werden anschaulich aus radialsymmetrischen linearen \
Gleichungen mit komplizierten analytischen Koeffizienten einfache lineare \
Gleichungen in nur einer Raumdimension.\
\>", "Text"],

Cell[TextData[{
  "Bei zwei Raumdimensionen oder bei den Abstandsgesetzen der Diffusion ist \
der Eulersche Trick (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Eulerscher Trick"],
  ") nicht \[UDoubleDot]blich, da aus der deduktiven Mathematik andere \
Resultate (z. B. ",
  ButtonBox["[Metz1996]",
    ButtonData:>{"Literatur.nb", "[Metz1996]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (6.4), S. 74) folgen, die den \[CapitalUDoubleDot]bergang in eine \
eindimensionale Gleichung verhindern."
}], "Text"],

Cell["\<\
Das spezifische Abstandsgesetz bei der Dynamik auf einer Kugeloberfl\
\[ADoubleDot]che ergibt etwa\
\>", "Text"],

Cell[BoxData[
    \(\(f[r] = 2  \[Pi]\ R\  | Sin[r\/R] | \ , \)\)], "NumberedEquation",
  CellTags->"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"],

Cell[TextData[{
  "wobei ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " den Bogenabstand auf der Kugeloberfl\[ADoubleDot]che und ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " den Radius der Kugel beschreibt. Der entsprechende Laplace-Operator f\
\[UDoubleDot]r Welle oder Diffusion ist auf unabh\[ADoubleDot]ngigem Wege \
bislang nicht hergeleitet worden."
}], "Text"],

Cell["\<\
Ein wesentlicher Unterschied zwischen einer Welle und der Diffusion besteht \
in mehreren Dimensionen darin, da\[SZ] bei der Diffusion das Raumintegral \
\[UDoubleDot]ber die Dichte eine Erhaltungsgr\[ODoubleDot]\[SZ]e (oft die \
Gesamtmasse) ist, w\[ADoubleDot]hrend bei der Welle das Raumintegral \
\[UDoubleDot]ber das Quadrat der Wellenl\[ODoubleDot]sung eine Erhaltungsgr\
\[ODoubleDot]\[SZ]e (in der Regel die Gesamtenergie) ist. Dieser Unterschied \
f\[ADoubleDot]llt bei der eindimensionalen Betrachtung nicht auf.\
\>", "Text"],

Cell[TextData[{
  "Um den Rahmen dieser Arbeit nicht v\[ODoubleDot]llig zu sprengen, werden \
im weiteren Verlauf haupts\[ADoubleDot]chlich noch Diskussionen in einer \
einzigen Raumdimension gef\[UDoubleDot]hrt, die sich zumindest mit Hilfe des \
Eulerschen Tricks (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Eulerscher Trick"],
  ") auf radialsymmetrische Probleme \[UDoubleDot]bertragen lassen."
}], "Text"],

Cell[TextData[{
  "Die Kombination des Abstandsgesetzes (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", 
  "Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"],
  ") mit dem Eulerschen Trick (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Eulerscher Trick"],
  ") kann im Rahmen eines eigenen hypothetischen Modells diskutiert werden, w\
\[ADoubleDot]hrend andere Verallgemeinerungen des Laplace-Operators im Rahmen \
anderer Modelle auch andere L\[ODoubleDot]sungen besitzen."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Beschreibung anomaler Diffusion"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Die Formel von Wei, Bechinger und Leiderer"
}], "Subsection"],

Cell[TextData[{
  "Wei Q.-H., C. Bechinger und P. Leiderer geben in ihrer Arbeit ",
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  " eine Normalverteilung mit einer Varianz an, die anomale Diffusion \
beschreibt. Diese Verteilung lautet (",
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (2), S. 627):"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x, t] = 
      \(\((Exp[\(-\(x\^2\/\(4  F\ t\^\[Alpha]\)\)\)]
              \/\@\(4  \[Pi]\ F\ t\^\[Alpha]\))\)\ .\)\)], "NumberedEquation",\

  CellTags->"Wei-Formel"],

Cell[TextData[{
  "In der genannten Arbeit werden auch weitere Quellen f\[UDoubleDot]r diese \
Verteilung zitiert, ohne da\[SZ] eine dynamische Gleichung zugrunde gelegt \
wird. Es handelt sich vielmehr um einen rein heuristischen Ansatz, mit dem \
das Ph\[ADoubleDot]nomen ",
  StyleBox["anomale Diffusion",
    FontSlant->"Italic"],
  " zumindest bez\[UDoubleDot]glich der Varianz korrekt beschrieben wird."
}], "Text"],

Cell["\<\
Die Autoren dieser Arbeit waren so freundlich, ihre Me\[SZ]daten zur weiteren \
Auswertung im Rahmen dieser Arbeit zur Verf\[UDoubleDot]gung zu stellen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Zeit-fraktionale Diffusionsgleichungen"
}], "Subsection"],

Cell[TextData[{
  "Schneider und Wyss geben in ihrer Arbeit ",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  " eine modifizierte Ficksche Diffusionsgleichung an, die den Riemannschen \
Integral-Operator verwendet und auch anomale Diffusion beschreibt."
}], "Text"],

Cell[TextData[{
  "Der Riemannsche Integral-Operator interpoliert die verschiedenen Ordnungen \
von Integration und Differentiation. Er ist sinnvoll definiert \
f\[UDoubleDot]r alle komplexen Differentiationsordnungen ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  ". Im Programmpaket ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " ist gleich der Riemann-Liouvillesche Differentiations-Operator angegeben \
(",
  ButtonBox["[SKM1993]",
    ButtonData:>{"Literatur.nb", "[SKM1993]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (2.32), S. 37), der f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  " zum Riemannschen Integral-Operator der Integrationsordnung ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Beta]\)\)]],
  " wird:"
}], "Text"],

Cell[BoxData[
    RowBox[{
    \(\[ScriptCapitalD]\_\(a, \ x\)\%\[Beta][f[x]] := 
        \(\((\[DifferentialD]\/\[DifferentialD]x)\)\^\[Eta]\) 
          \(1\/\[CapitalGamma][\[Eta] - \[Beta]]\) 
          \(\[Integral]\_a\%x\( f[y]\/\((x - y)\)\^\(\[Beta] - \[Eta] + 1\)\) 
              \[DifferentialD]y\)\), " ", ",", "\n", "\n", 
      RowBox[{"\[Eta]", "=", 
        RowBox[{"{", GridBox[{
             
               {\(\([\ Re[\[Beta]]\ ]\) + 1\ \ \ \ \ \ \ \ \ \ Re[\[Beta]] 
                  \[GreaterEqual] 0\ , \)},
             
               {\(\ \ \ \ \ \ \ \ \ \ \ \ \ 
                0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Re[\[Beta]] < 
                  \(0\ .\)\)}
              }]}]}]}]], "NumberedEquation",
  CellTags->"Riemann-Liouville-Operator"],

Cell[TextData[{
  "Der Riemann-Liouville-Operator stellt in rein integraler Darstellung (",
  Cell[BoxData[
      \(TraditionalForm\`Re[\[Beta]] < 0\)]],
  ") bei ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  " eine Laplace-Faltung mit einer Potenz-Funktion dar. Die physikalische \
Motivation des Riemann-Liouville-Operators wird immer wieder diskutiert. Ein \
m\[ODoubleDot]glicher Zugang wird im Abschnitt 3.1.1 dieser Arbeit \
angedeutet."
}], "Text"],

Cell[TextData[{
  "Da die Laplace-Transformation einer linearen Gleichung die \
Anfangswertprobleme des Systems liefert, gibt es allerhand analytische T\
\[UDoubleDot]cken, um eine zeit-fraktionale Gleichung mit konsistentem \
Anfangswertproblem aufzustellen. Derartige Fragen wurden bereits durch die \
Arbeiten von Schneider und Wyss (",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (1.1)-(1.5), S. 134), Gl\[ODoubleDot]ckle (",
  ButtonBox["[Gl\[ODoubleDot]1993]",
    ButtonData:>{"Literatur.nb", "[Gloe1993]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 3.3, S. 28-33) und schlie\[SZ]lich Wyss und Wyss ",
  ButtonBox["[WW1999]",
    ButtonData:>{"Literatur.nb", "[WW1999]"},
    ButtonStyle->"Hyperlink"],
  " erfolgreich abgehandelt."
}], "Text",
  PageBreakAbove->True],

Cell[TextData[{
  "Die Erg\[ADoubleDot]nzung der Gleichung von Schneider und Wyss um eine \
inhomogene Steuerkraft ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t]\)]],
  " ergibt die folgende Darstellungsweise der zeit-fraktionalen \
Diffusionsgleichung mit ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Beta] \[LessEqual] 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Rho]\_t[x, t] - 
        \[Lambda]\ 
          \[ScriptCapitalD]\_\(0, \ t\)\%\(1 - \[Beta]\)[
            \[Rho]\_\(x\ x\)[x, t]] = \(s[x, t]\ .\)\)], "NumberedEquation",
  CellTags->"zeit-fraktionale Diffusionsgleichung"],

Cell[TextData[{
  "Die integrierte Darstellung dieser Gleichung beinhaltet alle \
Anfangswertprobleme und bereitet dann auch bez\[UDoubleDot]glich der \
Laplace-Transformation keinerlei Probleme, hier wegen ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] > 0\)]],
  " (vgl. ",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (2.1), S. 135):"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x, t] - 
        \[Sum]\+\(n = 0\)\%\(\(-1\) - 
              \([\(-\[Beta]\)]
                \)\)\(\[PartialD]\^n \[Rho][x, t \[Rule] 0]\/\[PartialD]x\^n
                    \) t\^n\/\(n!\)\  - \ 
        \[Lambda]\ 
          \[ScriptCapitalD]\_\(0, \ t\)\%\(-\[Beta]\)[
            \[PartialD]\^2 \[Rho][x, t]\/\[PartialD]x\^2] = 
      \(\[ScriptCapitalD]\_\(0, \ t\)\%\(\(-1\) - \([\(-\[Beta]\)]\)\)[
          s[x, t]]\ .\)\)], "NumberedEquation",
  CellTags->"inhomogene Schneider-Wyss-Gleichung"],

Cell[TextData[{
  "In diesem Zusammenhang wurde ausgenutzt, da\[SZ] der Riemannsche \
Integraloperator eine Verallgemeinerung des iterierten Cauchyschen Integrals \
(",
  ButtonBox["[Non1996]",
    ButtonData:>{"Literatur.nb", "[Non1996]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. 2.2.2, S. 19) ist. Die Gau\[SZ]sche Treppenfunktion (",
  ButtonBox["[Wol1997]",
    ButtonData:>{"Literatur.nb", "[Wol1997]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. 3.2.2, S. 775) oder Gau\[SZ]klammer-Funktion wird durch eckige \
Klammern ",
  Cell[BoxData[
      \(TraditionalForm\`\([\ ]\)\)]],
  ", ohne f\[UDoubleDot]hrendes Symbol, gekennzeichnet."
}], "Text"],

Cell[TextData[{
  "Die beiden Darstellungen (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "zeit-fraktionale Diffusionsgleichung"],
  ") und (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "inhomogene Schneider-Wyss-Gleichung"],
  ") der zeit-fraktionalen Diffusionsgleichung interpolieren zwischen der \
Fickschen Diffusionsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") und der Wellengleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Wellen-Gleichung"],
  ") in einer einzigen Raumdimension. Die Varianz des Propagators von \
Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "inhomogene Schneider-Wyss-Gleichung"],
  ") ergibt also auch anschaulich ein zeitliches Potenzgesetz ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sigma]\^2\)~\(t\^\[Beta]\)\)]],
  " zur Beschreibung anomaler Diffusion, was im Rahmen dieser Arbeit noch n\
\[ADoubleDot]her (Kapitel 3) und anhand von Me\[SZ]beispielen (Kapitel 4 und \
5) ausgef\[UDoubleDot]hrt wird."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Orts-fraktionale Diffusionsgleichungen"
}], "Subsection"],

Cell[TextData[{
  "West et al. verwenden in ihrer Arbeit ",
  ButtonBox["[WGMN1997]",
    ButtonData:>{"Literatur.nb", "[WGMN1997]"},
    ButtonStyle->"Hyperlink"],
  " den symmetrischen Riesz-Operator, um eine gebrochenzahlige \
Ableitungsordnung anstelle des Laplace-Operators der Fickschen \
Diffusionsgleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") zu diskutieren. Es ergeben sich L\[ODoubleDot]sungsfunktionen mit L\
\[EAcute]vy-Asymptotik, die ebenfalls anomale Diffusion zu beschreiben \
scheinen."
}], "Text"],

Cell["\<\
Der Riesz-Operator wird im Abschnitt 2.3.2.6 dieser Arbeit in seinem \
mathematischen Umfeld vorgestellt.\
\>", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "Das Problem bei L\[EAcute]vy-verteilten Resultaten ist, da\[SZ] die damit \
theoretisch berechnete Varianz bei der Verwendung unendlicher \
Integrationsgrenzen divergiert. Diese Integrationsgrenzen der \
Momentenintegrale m\[UDoubleDot]ssen also mit den Abmesungen des \
Versuchsaufbaus harmonisiert werden, um das Varianztheorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") beim Vergleich von Theorie und Messung anwenden zu k\[ODoubleDot]nnen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Orts- und zeit-fraktionale Diffusionsgleichungen"
}], "Subsection"],

Cell["\<\
Eine Kombination von orts- und zeit-fraktionalen Diffusionsgleichungen kann \
aus didaktischen Gr\[UDoubleDot]nden erfolgen, um die analytische Rechnung \
nur einmal durchzuf\[UDoubleDot]hren und ein m\[ODoubleDot]glichst \
allgemeines Ergebnis zu erzielen.\
\>", "Text"],

Cell[TextData[{
  "Bez\[UDoubleDot]glich der Klassifikation von diffusivem Verhalten \
\[UDoubleDot]ber die Varianz erscheint dieser Ansatz zun\[ADoubleDot]chst \
einmal \[UDoubleDot]berparametrisiert, was dazu dienen kann, noch weitere \
Untersuchungen zur Theorie anzuschlie\[SZ]en. Das Verst\[ADoubleDot]ndnis der \
inhomogen erg\[ADoubleDot]nzten Gleichung von Schneider und Wyss (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "inhomogene Schneider-Wyss-Gleichung"],
  ") kann auf diese Weise vertieft werden."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Zusammenfassung"
}], "Section"],

Cell[TextData[{
  "Unabh\[ADoubleDot]ngig davon, ob eine Diffusionsgleichung parabolisch (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  "), elliptisch (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") oder diskret (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") ist, ergibt sich f\[UDoubleDot]r die Varianz des Propagators zumindest \
die Hypothese von der Proportionalit\[ADoubleDot]t zur Zeit, also normale \
Diffusion im Sinne der Einstein-Relation. Die hyperbolische \
Cattaneo-Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") der Diffusion besitzt nur asymptotisch f\[UDoubleDot]r gro\[SZ]e Zeiten \
die Varianz der normalen Diffusion."
}], "Text"],

Cell["\<\
Alle Diffusionsgleichungen sind lineare Gleichungen, was aus dem \
Superpositionsprinzip folgt.\
\>", "Text"],

Cell["\<\
Zur Beurteilung diffusiver Prozesse dient in erster Linie die auf die \
Startvarianz abgeglichene Varianz in ihrem zeitlichen Verhalten. Diese Art \
der Versuchsauswertung kann direkt mit der Varianz des theoretisch \
hergeleiteten Propagators verglichen werden.\
\>", "Text"],

Cell[TextData[{
  "Diffusive Prozesse besitzen eine streng monoton mit der Zeit ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " wachsende Varianz. Die Varianz des Diffusionspropagators \
gen\[UDoubleDot]gt einem Potenzgesetz in der Zeit."
}], "Text"],

Cell["\<\
Zur Modellierung anomaler Diffusion k\[ODoubleDot]nnen am einfachsten \
fraktionalisierte Ficksche Diffusionsgleichungen dienen, um die es im \
weiteren Verlauf dieser Arbeit schwerpunktm\[ADoubleDot]\[SZ]ig geht.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 746}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1248, 719},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->15,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Kapitel 1. Beschreibung von Diffusion"}], "Header"]}, {
    Cell[ 
        TextData[ {"Kapitel 1. Beschreibung von Diffusion"}], "Header"], 
      Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Kontinuit\[ADoubleDot]tsgleichung"->{
    Cell[3025, 108, 152, 3, 32, "NumberedEquation",
      CellTags->"Kontinuit\[ADoubleDot]tsgleichung"]},
  "1.Ficksches Gesetz"->{
    Cell[3904, 139, 140, 3, 32, "NumberedEquation",
      CellTags->"1.Ficksches Gesetz"]},
  "2.Ficksches Gesetz"->{
    Cell[5344, 180, 180, 4, 32, "NumberedEquation",
      CellTags->"2.Ficksches Gesetz"]},
  "Fickscher Diffusionspropagator"->{
    Cell[7146, 239, 209, 4, 66, "NumberedEquation",
      CellTags->"Fickscher Diffusionspropagator"]},
  "Normalverteilung"->{
    Cell[8670, 293, 199, 4, 68, "NumberedEquation",
      CellTags->"Normalverteilung"]},
  "Cattaneo-Gleichung"->{
    Cell[10238, 349, 233, 5, 32, "NumberedEquation",
      CellTags->"Cattaneo-Gleichung"]},
  "Diffusionskonstante"->{
    Cell[11142, 375, 110, 2, 33, "NumberedEquation",
      CellTags->"Diffusionskonstante"]},
  "Varianz der Cattaneo-Gleichung"->{
    Cell[12770, 424, 193, 4, 33, "NumberedEquation",
      CellTags->"Varianz der Cattaneo-Gleichung"]},
  "Differenzengleichung"->{
    Cell[19538, 635, 233, 4, 47, "NumberedEquation",
      CellTags->"Differenzengleichung"]},
  "Binomialverteilung"->{
    Cell[21812, 701, 759, 16, 60, "NumberedEquation",
      CellTags->"Binomialverteilung"]},
  "Varianz der Binomialverteilung"->{
    Cell[23981, 761, 292, 6, 47, "NumberedEquation",
      CellTags->"Varianz der Binomialverteilung"]},
  "modifizierte Cattaneo-Gleichung"->{
    Cell[25420, 812, 287, 5, 50, "NumberedEquation",
      CellTags->"modifizierte Cattaneo-Gleichung"]},
  "Binomialer Grenz\[UDoubleDot]bergang"->{
    Cell[28585, 919, 780, 17, 92, "NumberedEquation",
      CellTags->"Binomialer Grenz\[UDoubleDot]bergang"]},
  "Varianztheorem"->{
    Cell[35428, 1140, 317, 8, 73, "NumberedEquation",
      CellTags->"Varianztheorem"]},
  "Delta-Faltung"->{
    Cell[36253, 1162, 179, 3, 48, "NumberedEquation",
      CellTags->"Delta-Faltung"]},
  "Varianzabgleich"->{
    Cell[36799, 1181, 216, 4, 33, "NumberedEquation",
      CellTags->"Varianzabgleich"]},
  "Wellen-Gleichung"->{
    Cell[40882, 1324, 169, 4, 33, "NumberedEquation",
      CellTags->"Wellen-Gleichung"]},
  "Wellen-L\[ODoubleDot]sung"->{
    Cell[41167, 1335, 169, 4, 47, "NumberedEquation",
      CellTags->"Wellen-L\[ODoubleDot]sung"]},
  "Wellen-Varianz"->{
    Cell[41440, 1345, 108, 2, 33, "NumberedEquation",
      CellTags->"Wellen-Varianz"]},
  "Diffusionsvarianz"->{
    Cell[42914, 1399, 121, 2, 33, "NumberedEquation",
      CellTags->"Diffusionsvarianz"]},
  "Eulerscher Trick"->{
    Cell[49273, 1612, 243, 5, 53, "NumberedEquation",
      CellTags->"Eulerscher Trick"]},
  "Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"->{
    Cell[50386, 1645, 149, 2, 44, "NumberedEquation",
      CellTags->"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"]},
  "Wei-Formel"->{
    Cell[53285, 1734, 195, 5, 66, "NumberedEquation",
      CellTags->"Wei-Formel"]},
  "Riemann-Liouville-Operator"->{
    Cell[55412, 1800, 780, 17, 120, "NumberedEquation",
      CellTags->"Riemann-Liouville-Operator"]},
  "zeit-fraktionale Diffusionsgleichung"->{
    Cell[57872, 1865, 245, 5, 36, "NumberedEquation",
      CellTags->"zeit-fraktionale Diffusionsgleichung"]},
  "inhomogene Schneider-Wyss-Gleichung"->{
    Cell[58544, 1885, 532, 11, 63, "NumberedEquation",
      CellTags->"inhomogene Schneider-Wyss-Gleichung"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Kontinuit\[ADoubleDot]tsgleichung", 67126, 2137},
  {"1.Ficksches Gesetz", 67259, 2140},
  {"2.Ficksches Gesetz", 67377, 2143},
  {"Fickscher Diffusionspropagator", 67507, 2146},
  {"Normalverteilung", 67635, 2149},
  {"Cattaneo-Gleichung", 67751, 2152},
  {"Diffusionskonstante", 67871, 2155},
  {"Varianz der Cattaneo-Gleichung", 68003, 2158},
  {"Differenzengleichung", 68136, 2161},
  {"Binomialverteilung", 68257, 2164},
  {"Varianz der Binomialverteilung", 68389, 2167},
  {"modifizierte Cattaneo-Gleichung", 68533, 2170},
  {"Binomialer Grenz\[UDoubleDot]bergang", 68683, 2173},
  {"Varianztheorem", 68817, 2176},
  {"Delta-Faltung", 68928, 2179},
  {"Varianzabgleich", 69040, 2182},
  {"Wellen-Gleichung", 69155, 2185},
  {"Wellen-L\[ODoubleDot]sung", 69280, 2188},
  {"Wellen-Varianz", 69403, 2191},
  {"Diffusionsvarianz", 69518, 2194},
  {"Eulerscher Trick", 69635, 2197},
  {"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che", 69781, 2200},
  {"Wei-Formel", 69921, 2203},
  {"Riemann-Liouville-Operator", 70041, 2206},
  {"zeit-fraktionale Diffusionsgleichung", 70189, 2209},
  {"inhomogene Schneider-Wyss-Gleichung", 70344, 2212}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 49, 0, 69, "Subtitle"],

Cell[CellGroupData[{
Cell[1783, 53, 63, 0, 109, "Title"],

Cell[CellGroupData[{
Cell[1871, 57, 167, 5, 68, "Section"],

Cell[CellGroupData[{
Cell[2063, 66, 204, 7, 64, "Subsection"],
Cell[2270, 75, 271, 4, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2578, 84, 148, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[2751, 95, 192, 9, 51, "Subsubsection"],
Cell[2946, 106, 76, 0, 32, "Text"],
Cell[3025, 108, 152, 3, 32, "NumberedEquation",
  CellTags->"Kontinuit\[ADoubleDot]tsgleichung"],
Cell[3180, 113, 487, 16, 72, "Text"],
Cell[3670, 131, 231, 6, 32, "Text"],
Cell[3904, 139, 140, 3, 32, "NumberedEquation",
  CellTags->"1.Ficksches Gesetz"],
Cell[4047, 144, 752, 18, 112, "Text",
  PageBreakBelow->True],
Cell[4802, 164, 539, 14, 72, "Text"],
Cell[5344, 180, 180, 4, 32, "NumberedEquation",
  CellTags->"2.Ficksches Gesetz"],
Cell[5527, 186, 1040, 27, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6604, 218, 205, 9, 51, "Subsubsection"],
Cell[6812, 229, 331, 8, 52, "Text"],
Cell[7146, 239, 209, 4, 66, "NumberedEquation",
  CellTags->"Fickscher Diffusionspropagator"],
Cell[7358, 245, 313, 10, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7708, 260, 209, 9, 51, "Subsubsection"],
Cell[7920, 271, 747, 20, 92, "Text"],
Cell[8670, 293, 199, 4, 68, "NumberedEquation",
  CellTags->"Normalverteilung"],
Cell[8872, 299, 511, 15, 52, "Text"],
Cell[9386, 316, 140, 3, 52, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9575, 325, 185, 8, 64, "Subsection",
  PageBreakAbove->True],
Cell[9763, 335, 472, 12, 52, "Text"],
Cell[10238, 349, 233, 5, 32, "NumberedEquation",
  CellTags->"Cattaneo-Gleichung"],
Cell[10474, 356, 665, 17, 72, "Text"],
Cell[11142, 375, 110, 2, 33, "NumberedEquation",
  CellTags->"Diffusionskonstante"],
Cell[11255, 379, 264, 7, 52, "Text"],
Cell[11522, 388, 554, 15, 72, "Text"],
Cell[12079, 405, 688, 17, 92, "Text"],
Cell[12770, 424, 193, 4, 33, "NumberedEquation",
  CellTags->"Varianz der Cattaneo-Gleichung"],
Cell[12966, 430, 959, 24, 116, "Text",
  PageBreakBelow->True],
Cell[13928, 456, 708, 21, 76, "Text"],
Cell[14639, 479, 736, 16, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15412, 500, 174, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[15611, 511, 214, 9, 51, "Subsubsection"],
Cell[15828, 522, 403, 11, 53, "Text"],
Cell[16234, 535, 409, 8, 92, "Text"],
Cell[16646, 545, 178, 3, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16861, 553, 213, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[17077, 565, 462, 10, 92, "Text"],
Cell[17542, 577, 1059, 24, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18638, 606, 197, 10, 51, "Subsubsection"],
Cell[18838, 618, 697, 15, 112, "Text"],
Cell[19538, 635, 233, 4, 47, "NumberedEquation",
  CellTags->"Differenzengleichung"],
Cell[19774, 641, 464, 9, 92, "Text"],
Cell[20241, 652, 672, 13, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20950, 670, 238, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[21191, 682, 618, 17, 72, "Text"],
Cell[21812, 701, 759, 16, 60, "NumberedEquation",
  CellTags->"Binomialverteilung"],
Cell[22574, 719, 506, 14, 56, "Text"],
Cell[23083, 735, 895, 24, 93, "Text"],
Cell[23981, 761, 292, 6, 47, "NumberedEquation",
  CellTags->"Varianz der Binomialverteilung"],
Cell[24276, 769, 283, 9, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24596, 783, 253, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[24852, 795, 565, 15, 72, "Text"],
Cell[25420, 812, 287, 5, 50, "NumberedEquation",
  CellTags->"modifizierte Cattaneo-Gleichung"],
Cell[25710, 819, 786, 20, 92, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26545, 845, 147, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[26717, 856, 230, 9, 51, "Subsubsection"],
Cell[26950, 867, 1285, 38, 92, "Text"],
Cell[28238, 907, 344, 10, 32, "Text"],
Cell[28585, 919, 780, 17, 92, "NumberedEquation",
  CellTags->"Binomialer Grenz\[UDoubleDot]bergang"],
Cell[29368, 938, 345, 8, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29750, 951, 216, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[29969, 963, 578, 18, 52, "Text"],
Cell[30550, 983, 1208, 28, 152, "Text"],
Cell[31761, 1013, 1008, 26, 132, "Text"],
Cell[32772, 1041, 390, 9, 72, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33223, 1057, 144, 6, 68, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[33392, 1067, 187, 8, 64, "Subsection"],

Cell[CellGroupData[{
Cell[33604, 1079, 178, 9, 51, "Subsubsection"],
Cell[33785, 1090, 216, 4, 52, "Text"],
Cell[34004, 1096, 303, 5, 72, "Text"],
Cell[34310, 1103, 293, 5, 72, "Text"],
Cell[34606, 1110, 139, 3, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34782, 1118, 185, 9, 51, "Subsubsection"],
Cell[34970, 1129, 455, 9, 92, "Text"],
Cell[35428, 1140, 317, 8, 73, "NumberedEquation",
  CellTags->"Varianztheorem"],
Cell[35748, 1150, 502, 10, 92, "Text"],
Cell[36253, 1162, 179, 3, 48, "NumberedEquation",
  CellTags->"Delta-Faltung"],
Cell[36435, 1167, 361, 12, 52, "Text",
  PageBreakAbove->True],
Cell[36799, 1181, 216, 4, 33, "NumberedEquation",
  CellTags->"Varianzabgleich"],
Cell[37018, 1187, 116, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37171, 1195, 200, 9, 51, "Subsubsection"],
Cell[37374, 1206, 314, 5, 72, "Text"],
Cell[37691, 1213, 340, 6, 72, "Text"],
Cell[38034, 1221, 504, 14, 72, "Text"],
Cell[38541, 1237, 151, 3, 52, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38741, 1246, 196, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[38962, 1257, 216, 9, 51, "Subsubsection"],
Cell[39181, 1268, 494, 11, 72, "Text"],
Cell[39678, 1281, 518, 13, 72, "Text"],
Cell[40199, 1296, 370, 9, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40606, 1310, 235, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[40844, 1322, 35, 0, 32, "Text"],
Cell[40882, 1324, 169, 4, 33, "NumberedEquation",
  CellTags->"Wellen-Gleichung"],
Cell[41054, 1330, 110, 3, 32, "Text"],
Cell[41167, 1335, 169, 4, 47, "NumberedEquation",
  CellTags->"Wellen-L\[ODoubleDot]sung"],
Cell[41339, 1341, 98, 2, 32, "Text"],
Cell[41440, 1345, 108, 2, 33, "NumberedEquation",
  CellTags->"Wellen-Varianz"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41585, 1352, 212, 9, 51, "Subsubsection"],
Cell[41800, 1363, 509, 14, 72, "Text"],
Cell[42312, 1379, 599, 18, 73, "Text"],
Cell[42914, 1399, 121, 2, 33, "NumberedEquation",
  CellTags->"Diffusionsvarianz"],
Cell[43038, 1403, 286, 9, 32, "Text"],
Cell[43327, 1414, 147, 5, 32, "Text"],
Cell[43477, 1421, 142, 5, 32, "Text"],
Cell[43622, 1428, 149, 5, 32, "Text"],
Cell[43774, 1435, 148, 5, 32, "Text"],
Cell[43925, 1442, 150, 6, 32, "Text",
  PageBreakBelow->True],
Cell[44078, 1450, 952, 29, 92, "Text"],
Cell[45033, 1481, 344, 6, 72, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[45426, 1493, 172, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[45623, 1504, 202, 9, 51, "Subsubsection"],
Cell[45828, 1515, 790, 14, 132, "Text"],
Cell[46621, 1531, 471, 12, 72, "Text"],
Cell[47095, 1545, 388, 8, 72, "Text"],
Cell[47486, 1555, 362, 6, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47885, 1566, 216, 9, 51, "Subsubsection"],
Cell[48104, 1577, 314, 8, 52, "Text"],
Cell[48421, 1587, 396, 9, 72, "Text",
  PageBreakAbove->True],
Cell[48820, 1598, 450, 12, 99, "Text"],
Cell[49273, 1612, 243, 5, 53, "NumberedEquation",
  CellTags->"Eulerscher Trick"],
Cell[49519, 1619, 209, 4, 52, "Text"],
Cell[49731, 1625, 527, 13, 72, "Text"],
Cell[50261, 1640, 122, 3, 32, "Text"],
Cell[50386, 1645, 149, 2, 44, "NumberedEquation",
  CellTags->"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"],
Cell[50538, 1649, 385, 10, 72, "Text"],
Cell[50926, 1661, 546, 8, 92, "Text"],
Cell[51475, 1671, 434, 9, 72, "Text"],
Cell[51912, 1682, 525, 13, 72, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52498, 1702, 147, 6, 68, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[52670, 1712, 172, 7, 64, "Subsection"],
Cell[52845, 1721, 437, 11, 52, "Text"],
Cell[53285, 1734, 195, 5, 66, "NumberedEquation",
  CellTags->"Wei-Formel"],
Cell[53483, 1741, 421, 8, 72, "Text"],
Cell[53907, 1751, 176, 3, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54120, 1759, 168, 7, 64, "Subsection"],
Cell[54291, 1768, 323, 7, 52, "Text"],
Cell[54617, 1777, 792, 21, 92, "Text"],
Cell[55412, 1800, 780, 17, 120, "NumberedEquation",
  CellTags->"Riemann-Liouville-Operator"],
Cell[56195, 1819, 466, 11, 72, "Text"],
Cell[56664, 1832, 847, 19, 112, "Text",
  PageBreakAbove->True],
Cell[57514, 1853, 355, 10, 52, "Text"],
Cell[57872, 1865, 245, 5, 36, "NumberedEquation",
  CellTags->"zeit-fraktionale Diffusionsgleichung"],
Cell[58120, 1872, 421, 11, 72, "Text"],
Cell[58544, 1885, 532, 11, 63, "NumberedEquation",
  CellTags->"inhomogene Schneider-Wyss-Gleichung"],
Cell[59079, 1898, 651, 16, 92, "Text"],
Cell[59733, 1916, 1112, 29, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60882, 1950, 168, 7, 64, "Subsection"],
Cell[61053, 1959, 574, 14, 92, "Text"],
Cell[61630, 1975, 153, 4, 32, "Text",
  PageBreakBelow->True],
Cell[61786, 1981, 523, 10, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62346, 1996, 178, 7, 64, "Subsection"],
Cell[62527, 2005, 281, 5, 72, "Text"],
Cell[62811, 2012, 546, 10, 92, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63406, 2028, 107, 5, 68, "Section"],
Cell[63516, 2035, 861, 22, 92, "Text"],
Cell[64380, 2059, 119, 3, 32, "Text"],
Cell[64502, 2064, 286, 5, 72, "Text"],
Cell[64791, 2071, 257, 6, 52, "Text"],
Cell[65051, 2079, 237, 4, 52, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

